Contributing 🤝
---------------

Thank you for your interest in lstmcpipe. We appreciate your willingness to contribute. Here are some guidelines to help you get started.

How to Contribute?
******************

Ask to admins to be added to the GitHub CTA organization and to the lst-dev group.
This will allow you to create branches and pull requests in the lstmcpipe repository.

Reporting Bugs
**************

If you find a bug in the code, please open an issue on GitHub. Make sure to include a clear description of the bug and how to reproduce it. If you can, include a code snippet or a small example that reproduces the bug.

Reporting issues in MC productions
**********************************

If you find an issue in the MC productions, please open an issue on GitHub. Make sure to include a clear description of the issue and findings if you have done any investigation. You may also check the logs in the data directories.

Code contributions
******************

If you are unsure about the contribution you want to make, please open an issue first to discuss it with the maintainers.

Clone the repository and create a new branch.
Install lstmcpipe following the instructions for developers in the README file.

Commit Your Changes: Commit your changes in your branch. Make sure to follow good practices for commit messages.

Push Your Changes: Push your changes to GitHub. This is the first step in sharing your improvements with us.

Create a Pull Request: On GitHub, create a new Pull Request to our project. Make sure to describe and explain it sufficiently so we can understand what you are trying to do.

Review: Now it's our turn to work! We will look at your Pull Request to ensure it can be integrated into the project. We might ask you to make changes if we think it will improve your contribution.

Merge: Once we have decided that your Pull Request is ready, we will merge it into the project. We thank you for this!


Specific Path Configs
*********************

If you developed a new path configuration, you may contribute it as it can benefit other analyzers.
Follow the same steps as for code contributions.

Suggesting Enhancements
***********************

If you have an idea for a new feature or an enhancement to the code, please open an issue on GitHub. Make sure to include a clear description of the feature or enhancement you would like to see.
